### Replication script for: 
### "Distributing democratic influence: external efficacy and the preferred influence of policy winners and losers"
### Anthony Kevins 
### International Journal of Public Opinion Research
### Cite this dataset: Kevins, Anthony (2022): Replication Materials: Distributing democratic influence: external efficacy and the preferred influence of policy winners and losers. Loughborough University. Dataset. https://doi.org/10.17028/rd.lboro.21655730

## User guide:
# Ensure all required packages are installed (in RStudio you should be prompted to install missing packages)
# Press Ctrl-Shift-S in RStudio to run this script
# Note: the script and data files should be in the same folder; after running the script, all figures and tables will be in that folder

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(MASS) # For robustness check with ordered logit
library(psych) # For index analysis
library(tidyverse) # For data manipulation
library(plyr) # For data manipulation
library(stargazer) # For regression tables 
library(margins) # For marginal effects calculations 
library(grid) # For graph manipulation
library(ggpubr) # For figures 
library(table1) # For demographics table  
library(ggtext) # For html/markdown in ggplot labels 
library(equatiomatic) # For outputting regression equations into latex format

# Set colour scheme
col_scheme <- c("#008FD5", "#FF2700", "#030303", "#cfcfcf")

## Data set prep

# Read data file 
democracy <- read_csv("democracy.csv")

## Dataset prep 

# Prepare categorical variables/labels for tables

democracy$education_cat <- cut(democracy$education,
                               breaks=c(-Inf, 2, 3, 5, Inf),
                               labels=c(1, 2, 3, 4))
democracy$income_cat <- democracy$income
democracy$citizens_details_cat <- democracy$citizens_details
democracy$citizens_vote_cat <- democracy$citizens_vote
democracy$winners_details_cat <- democracy$winners_details
democracy$winners_vote_cat <- democracy$winners_vote
democracy$losers_details_cat <- democracy$losers_details
democracy$losers_vote_cat <- democracy$losers_vote

# Convert numeric variables to factor

democracy <- democracy %>%
    mutate(polinterest = factor(polinterest, levels = 1:4,
                                labels = c("Not at all interested", 
                                           "Little interested", 
                                           "Fairly interested", 
                                           "Very interested")))

democracy <- democracy %>%
    mutate(region = factor(region, levels = 1:4,
                           labels = c("Northeast", 
                                      "Midwest", 
                                      "West", 
                                      "South")))

democracy$pid_3 <- factor(democracy$pid_3)

democracy$pid_str <- factor(democracy$pid_str)

democracy <- democracy %>%
    mutate(female = factor(female, levels = 0:1,
                           labels = c("Male",
                                      "Female")))

democracy <- democracy %>%
    mutate(education_cat = factor(education_cat, levels = 1:4,
                                  labels = c("Highschool or Less",
                                             "Some College",
                                             "College Degree",
                                             "Post-grad Degree")))

democracy$minority <- ifelse(democracy$minority == "White", 0, ifelse(democracy$minority == "1", 1, NA))

democracy <- democracy %>%
    mutate(minority = factor(minority, levels = 0:1,
                             labels = c("White",
                                        "Non-White")))

democracy <- democracy %>%
    mutate(age = factor(age, levels = 2:7,
                        labels = c("18-24",
                                   "25-34",
                                   "35-44",
                                   "45-54",
                                   "55-64",
                                   "65+")))

democracy <- democracy %>%
    mutate(income_cat = factor(income_cat, levels = 1:12,
                               labels = c("<10k",
                                          "≥10k, <20k",
                                          "≥20k, <30k",
                                          "≥30k, <40k",
                                          "≥40k, <50k",
                                          "≥50k, <60k",
                                          "≥60k, <70k",
                                          "≥70k, <80k",
                                          "≥80k, <90k",
                                          "≥90k, <100k",
                                          "≥100k, <150k",
                                          "≥ 150k")))

democracy <- democracy %>%
    mutate(citizens_vote_cat = factor(citizens_vote_cat, levels = 1:5,
                                      labels = c("None at All", 
                                                 "Very Little", 
                                                 "Some", 
                                                 "A Lot", 
                                                 "A Great Deal")))

democracy <- democracy %>%
    mutate(citizens_details_cat = factor(citizens_details_cat, levels = 1:5,
                                         labels = c("None at All", 
                                                    "Very Little", 
                                                    "Some", 
                                                    "A Lot", 
                                                    "A Great Deal")))

democracy <- democracy %>%
    mutate(winners_details_cat = factor(winners_details_cat, levels = 1:5,
                                        labels = c("A Lot Less", 
                                                   "A Bit Less", 
                                                   "The Same", 
                                                   "A Bit More", 
                                                   "A Lot More")))

democracy <- democracy %>%
    mutate(winners_vote_cat = factor(winners_vote_cat, levels = 1:5,
                                     labels = c("A Lot Less", 
                                                "A Bit Less", 
                                                "The Same", 
                                                "A Bit More", 
                                                "A Lot More")))

democracy <- democracy %>%
    mutate(losers_details_cat = factor(losers_details_cat, levels = 1:5,
                                       labels = c("A Lot Less", 
                                                  "A Bit Less", 
                                                  "The Same", 
                                                  "A Bit More", 
                                                  "A Lot More")))


democracy <- democracy %>%
    mutate(losers_vote_cat = factor(losers_vote_cat, levels = 1:5,
                                    labels = c("A Lot Less", 
                                               "A Bit Less", 
                                               "The Same", 
                                               "A Bit More", 
                                               "A Lot More")))

# To standardise across the analysis, exclude observations missing any required data (remove libcon first; not used in analysis)
colnames(democracy)[colSums(is.na(democracy)) > 0] # Confirm columns with missing observations
democracy <- subset(democracy, select = -libcon)
democracy_full <- democracy 
democracy <- democracy %>% drop_na()

# Demographic Table (both full sample and used sample) 
democracy_full$in_analysis <- as.factor(complete.cases(democracy_full))
labels <- list(
    variables=list(female = "Sex", 
                   region = "Region", 
                   race_cat = "Race", 
                   age = "Age Bracket", 
                   income_cat = "Income Bracket", 
                   education_cat = "Education", 
                   pid_3 = "Partisan ID", 
                   pid_str = "Partisan Strength"),
    groups=list("", "Data Available for All Variables?"))
levels(democracy_full$in_analysis) <- c("No - Excluded", "Yes - In Analysis") # Set labels

strata <- c(list(Total=democracy_full), split(democracy_full, democracy_full$in_analysis)) # Set order 

dem_table <- table1(strata, labels, groupspan=c(1,2))

# Test for index justification
citizens_test <- democracy %>% 
    dplyr::select(citizens_details, citizens_vote)
citizens_test_results <- psych::alpha(citizens_test)
summary(citizens_test_results)
principal(citizens_test, nfactors=2, rotate="varimax")

winners_test <- democracy %>% 
    dplyr::select(winners_details, winners_vote)
winners_test_results <- psych::alpha(winners_test)
summary(winners_test_results)
principal(winners_test, nfactors=2, rotate="varimax")

losers_test <- democracy %>% 
    dplyr::select(losers_details, losers_vote)
losers_test_results <- psych::alpha(losers_test)
summary(losers_test_results)
principal(losers_test, nfactors=2, rotate="varimax")


# Generate indices
democracy$citizens_influence <- ((democracy$citizens_details + democracy$citizens_vote)/2)
democracy %>% 
    dplyr::select(citizens_details, citizens_vote, citizens_influence) 

democracy$winners_influence <- ((democracy$winners_details + democracy$winners_vote)/2)
democracy %>% 
    dplyr::select(winners_details, winners_vote, winners_influence) 

democracy$losers_influence <- ((democracy$losers_details + democracy$losers_vote)/2)
democracy %>% 
    dplyr::select(losers_details, losers_vote, losers_influence) 

# Test the relationship between the three indices

index_test <- democracy %>% 
    dplyr::select(citizens_influence, winners_influence, losers_influence)
index_test_results <- psych::alpha(index_test)
summary(index_test_results)

# Test whether responses to the two winners and losers questions are statistically different; overall, then differentiating more versus less influence

democracy %>%
    select(losers_influence, winners_influence) %>%
    pivot_longer(cols = everything()) %>%
    group_by(name) %>%
    dplyr::summarise(mean = mean(value),
                     stdv = sd(value)) %>%
    ggplot(aes(x = as.factor(name), y = mean, fill = name)) + 
    geom_bar(stat="identity", color="black", 
             position=position_dodge()) +
    geom_errorbar(aes(ymin=mean-stdv, ymax=mean+stdv), width=.2,
                  position=position_dodge(.9))

t.test(democracy$losers_influence, democracy$winners_influence)
wilcox.test(democracy$losers_influence, democracy$winners_influence, paired = TRUE) # tougher test, assumes non-normality

democracy <- democracy %>% 
    mutate(losers_influence_more = case_when(losers_influence > 3 ~ 1,
                           TRUE ~ 0),
           losers_influence_less = case_when(losers_influence < 3 ~ 1,
                                             TRUE ~ 0),
           winners_influence_more = case_when(winners_influence > 3 ~ 1,
                                             TRUE ~ 0),
           winners_influence_less = case_when(winners_influence < 3 ~ 1,
                                              TRUE ~ 0))

wilcox.test(democracy$losers_influence_more, democracy$winners_influence_more, paired = TRUE)

wilcox.test(democracy$losers_influence_less, democracy$winners_influence_less, paired = TRUE)

library(Kendall)
summary(Kendall(democracy$losers_influence, democracy$winners_influence))


## Dependent and Explanatory Variables - Descriptive Table 

label(democracy$citizens_details) <- "Average Americans: Influence on Content"
label(democracy$citizens_vote) <- "Average Americans: Influence on Vote"
label(democracy$citizens_influence) <- "Average Americans: Combined Index"
label(democracy$losers_details) <- "Negatively Affected Citizens: Influence on Content"
label(democracy$losers_vote) <- "Negatively Affected Citizens: Influence on Vote"
label(democracy$losers_influence) <- "Negatively Affected Citizens: Combined Index"
label(democracy$winners_details) <- "Positively Affected Citizens: Influence on Content"
label(democracy$winners_vote) <- "Positively Affected Citizens: Influence on Vote"
label(democracy$winners_influence) <- "Positively Affected Citizens: Combined Index"
label(democracy$extefficacy_factor) <- "External Efficacy"

dv_iv_table <- table1(~ citizens_details + citizens_vote + citizens_influence + 
                          losers_details + losers_vote + losers_influence +
                          winners_details + winners_vote + winners_influence +
                          extefficacy_factor,
                      data=democracy, overall="Total")

## Histograms

# Generate Tallies
dfcd <- democracy %>% 
    group_by(citizens_details_cat) %>%
    tally()
dfcv <- democracy %>% 
    group_by(citizens_vote_cat) %>%
    tally()
dfci <- democracy %>% 
    group_by(as.factor(citizens_influence)) %>%
    tally()

dfwd <- democracy %>% 
    group_by(winners_details_cat) %>%
    tally()
dfwv <- democracy %>% 
    group_by(winners_vote_cat) %>%
    tally()
dfwi <- democracy %>% 
    group_by(as.factor(winners_influence)) %>%
    tally()

dfld <- democracy %>% 
    group_by(losers_details_cat) %>%
    tally()
dflv <- democracy %>% 
    group_by(losers_vote_cat) %>%
    tally()
dfli <- democracy %>% 
    group_by(as.factor(losers_influence)) %>%
    tally()

# Create facet labels and standardise variable names
dfcv$group <- "Average Americans"
dfcv$influence <- "Influence on Vote"
dfcv <- rename(dfcv,c('citizens_vote_cat'='Response'))

dfcd$group <- "Average Americans"
dfcd$influence <- "Influence on Content"
dfcd <- rename(dfcd,c('citizens_details_cat'='Response'))

dfci$group <- "Average Americans"
dfci$influence <- "Influence"
dfci <- rename(dfci,c('as.factor(citizens_influence)'='Response'))

dfwv$group <- "Positively Affected Citizens"
dfwv$influence <- "Influence on Vote"
dfwv <- rename(dfwv,c('winners_vote_cat'='Response'))

dfwd$group <- "Positively Affected Citizens"
dfwd$influence <- "Influence on Content"
dfwd <- rename(dfwd,c('winners_details_cat'='Response'))

dfwi$group <- "Positively Affected Citizens"
dfwi$influence <- "Influence"
dfwi <- rename(dfwi,c('as.factor(winners_influence)'='Response'))

dfld$group <- "Negatively Affected Citizens"
dfld$influence <- "Influence on Content"
dfld <- rename(dfld,c('losers_details_cat'='Response'))

dflv$group <- "Negatively Affected Citizens"
dflv$influence <- "Influence on Vote"
dflv <- rename(dflv,c('losers_vote_cat'='Response'))

dfli$group <- "Negatively Affected Citizens"
dfli$influence <- "Influence"
dfli <- rename(dfli,c('as.factor(losers_influence)'='Response'))

# Combine dfs
histo_c_df <- rbind.fill(dfcv, dfcd)

histo_lw_df <- rbind.fill(dfwv, dfwd, dfld, dflv)

histo_cl_df <- rbind.fill(dfci, dfli)
histo_cw_df <- rbind.fill(dfci, dfwi)

# Calculate percentages for in-text discussion
summary((democracy$citizens_details))
summary((democracy$citizens_vote))

prop.table(table(democracy$citizens_details))
prop.table(table(democracy$citizens_vote))
prop.table(table(democracy$citizens_influence))

prop.table(table(democracy$winners_details))
prop.table(table(democracy$winners_vote))
prop.table(table(democracy$losers_details))
prop.table(table(democracy$losers_vote))

# Create custom label for indices 
winner_loser_labels <- c("A Lot Less", "", "A Bit Less", "", "The Same", "", "A Bit More", "", "A Lot More")

# Plot

g_lw_histogram <- ggplot(histo_lw_df, aes(x = n, fill = influence)) +
    geom_bar(aes(x = Response, y = n), position = "dodge", 
             stat = "identity", colour="grey50") +
    scale_fill_manual(values = c(col_scheme[1], "white")) +
    xlab("\nInfluence Relative to the Average American") + 
    ylab("Count") + 
    facet_grid( ~ group) +
    labs(fill = "Dependent Variable:", alpha = "Dependent Variable:") +
    theme(legend.position = "bottom", legend.title  = element_text(size = 22), text = element_text(size = 26),
          axis.text.x = element_text(size=16), strip.text.x = element_text(size = 28),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    scale_color_manual(values = col_scheme) +
    scale_y_continuous(expand = c(0,10))

ggsave(dpi = 900, file="Online Appendix Figure 1.png", g_lw_histogram, width = 14, height = 8)

g_c_histogram <- ggplot(histo_c_df, aes(x = n, fill = influence)) +
    geom_bar(aes(x = Response, y = n), position = "dodge", 
             stat = "identity", colour="grey50") +
    scale_fill_manual(values = c(col_scheme[1], "white")) +
    xlab("\nPreferred Influence of Average American") + 
    ylab("Count") + 
    labs(fill = "Dependent Variable:", alpha = "Dependent Variable:") +
    theme(legend.position = "bottom", legend.title = element_text(size=10),
          text = element_text(size = 13), legend.text = element_text(size=10),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    scale_color_manual(values = col_scheme) +
    scale_y_continuous(expand = c(0,10))

ggsave(dpi = 900, file="Online Appendix Figure 2.png", g_c_histogram)

histogram <- democracy %>%
    mutate(losers = ((losers_details + losers_vote)/2),
           winners = ((winners_details + winners_vote)/2)) %>% 
    select(losers, winners) %>% 
    pivot_longer(c(losers, winners), names_to = "group", values_to = "response") %>%
    group_by(group, response) %>%
    count() %>%
    ggplot(aes(x = as.factor(response), fill = group)) +
    geom_bar(aes(y = freq), position = "dodge", 
             stat = "identity", colour="grey50") +
    scale_fill_manual(labels = c("Negatively Affected Citizens", "Positively Affected Citizens"), values = c(col_scheme[1], "white")) +
    xlab("\nInfluence Relative to the Average American") + 
    ylab("Count") + 
    scale_x_discrete(labels = winner_loser_labels) +
    labs(fill = "Dependent Variable:", alpha = "Dependent Variable:") +
    theme(legend.position = "bottom", legend.title  = element_text(size = 14), text = element_text(size = 16),
          axis.text.x = element_text(size=12), strip.text.x = element_text(size = 16),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    scale_color_manual(values = col_scheme) +
    scale_y_continuous(expand = c(0,10))

ggsave(dpi = 900, file="Online Appendix Figure 3.png", histogram, width = 8, height = 7)

## Relationship between the "details" and "vote" variants of the question, for citizens and for policy winners versus losers

# Create frequency dfs 
runningcounts_citizens <- as.data.frame(table(as.numeric(democracy$citizens_details), as.numeric(democracy$citizens_vote)))
runningcounts_citizens_winners <- as.data.frame(table(as.numeric(democracy$citizens_influence), as.numeric(democracy$winners_influence)))
runningcounts_citizens_losers <- as.data.frame(table(as.numeric(democracy$citizens_influence), as.numeric(democracy$losers_influence)))
runningcounts_winners_losers <- as.data.frame(table(as.numeric(democracy$winners_influence), as.numeric(democracy$losers_influence)))

runningcounts_losers <- as.data.frame(table(as.numeric(democracy$losers_details), as.numeric(democracy$losers_vote)))
runningcounts_winners <- as.data.frame(table(democracy$winners_details, democracy$winners_vote))
runningcounts_details <- as.data.frame(table(democracy$losers_details, democracy$winners_details))
runningcounts_vote <- as.data.frame(table(democracy$losers_vote, democracy$winners_vote))

# Avoid centre square making the rest of the chart unreadable for the winners/losers graphs: replace with no colour/text of n
runningcounts_losers$centre_square <- as.character(runningcounts_losers$Freq)
runningcounts_losers$Freq[runningcounts_losers$Var1 == 3 & runningcounts_losers$Var2 == 3] <- NA

runningcounts_winners$centre_square <- as.character(runningcounts_winners$Freq)
runningcounts_winners$Freq[runningcounts_winners$Var1 == 3 & runningcounts_winners$Var2 == 3] <- NA

runningcounts_details$centre_square <- as.character(runningcounts_details$Freq)
runningcounts_details$Freq[runningcounts_details$Var1 == 3 & runningcounts_details$Var2 == 3] <- NA

runningcounts_vote$centre_square <- as.character(runningcounts_vote$Freq)
runningcounts_vote$Freq[runningcounts_vote$Var1 == 3 & runningcounts_vote$Var2 == 3] <- NA

# Find largest value to standardise gradient across the four-panel figure (268, rounded to 300 for the legend)
max(runningcounts_losers$Freq, na.rm = TRUE)
max(runningcounts_winners$Freq, na.rm = TRUE)
max(runningcounts_details$Freq, na.rm = TRUE)
max(runningcounts_vote$Freq, na.rm = TRUE)

# Calculate distribution of values for in-text discussion
winners_equals_losers <- runningcounts_winners_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(Var1 == Var2) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    filter(Var1 != 3 & Var2 !=3) %>% 
    mutate(Excluding_middle_group = sum(Freq),
           Excluding_middle_group_percent = Excluding_middle_group/sample_size,
           Middle_group_percent = (Total - Excluding_middle_group)/sample_size) %>%
    slice(1) %>%
    select(Total, Total_percent, Excluding_middle_group, Excluding_middle_group_percent, Middle_group_percent)
    
winners_morethan_losers <- runningcounts_winners_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) > as.numeric(Var2)) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

winners_lessthan_losers <- runningcounts_winners_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) < as.numeric(Var2)) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)


citizens_equals_winners <- runningcounts_citizens_winners %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(Var1 == Var2) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    filter(Var1 != 3 & Var2 !=3) %>% 
    mutate(Excluding_middle_group = sum(Freq),
           Excluding_middle_group_percent = Excluding_middle_group/sample_size,
           Middle_group_percent = (Total - Excluding_middle_group)/sample_size) %>%
    slice(1) %>%
    select(Total, Total_percent, Excluding_middle_group, Excluding_middle_group_percent, Middle_group_percent)

citizens_lots_winners_little <- runningcounts_citizens_winners %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) > 5, as.numeric(Var2) < 5) %>% ## NB: 3 factor format = 5 numeric format
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

citizens_atleastsome_winners_equal <- runningcounts_citizens_winners %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) >= 5 & as.numeric(Var2) == 5) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

citizens_little_winners_lots <- runningcounts_citizens_winners %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) < 5 & as.numeric(Var2) > 5) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)


citizens_equals_losers <- runningcounts_citizens_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(Var1 == Var2) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    filter(Var1 != 3 & Var2 !=3) %>% 
    mutate(Excluding_middle_group = sum(Freq),
           Excluding_middle_group_percent = Excluding_middle_group/sample_size,
           Middle_group_percent = (Total - Excluding_middle_group)/sample_size) %>%
    slice(1) %>%
    select(Total, Total_percent, Excluding_middle_group, Excluding_middle_group_percent, Middle_group_percent)

citizens_lots_losers_little <- runningcounts_citizens_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) > 5 & as.numeric(Var2) < 5) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

citizens_atleastsome_losers_equal <- runningcounts_citizens_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) >= 5 & as.numeric(Var2) == 5) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

citizens_little_losers_lots <- runningcounts_citizens_losers %>% 
    mutate(sample_size = sum(Freq)) %>% 
    filter(as.numeric(Var1) < 5 & as.numeric(Var2) > 5) %>% 
    mutate(Total = sum(Freq),
           Total_percent = Total/sample_size) %>% 
    slice(1) %>%
    select(Total, Total_percent)

# Plots graphs

g_pl <- ggplot(runningcounts_losers, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 300), breaks=seq(0, 600, by = 100)) + 
    geom_text(aes(label = paste0(centre_square), color = is.na(Freq))) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(plot.title = element_text(size=14),
          text = element_text(size = 14),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    labs(subtitle = "Panel A: Negatively Affected Citizens", x = "Influence on Content", y = "Influence on Vote")

g_pw <- ggplot(runningcounts_winners, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 600)) + 
    geom_text(aes(label = paste0(centre_square), color = is.na(Freq))) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(plot.title = element_text(size=14),
          text = element_text(size = 14),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    labs(subtitle = "Panel B: Positively Affected Citizens", x = "Influence on Content", y = "Influence on Vote")

g_c <- ggplot(runningcounts_citizens, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 650), breaks=seq(0, 650, by = 100)) + 
    geom_text(aes(label = paste0(Freq), color = Freq > 500)) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005)),
          legend.position = "bottom",
          legend.key.width = unit(1.9, "cm"),
          legend.key.height = unit(1.75, "cm"),
          legend.title = element_text(size = 14),
          legend.text = element_text(size = 11, colour = "gray40"),
          text = element_text(size = 14)) +
    guides(fill = guide_colourbar(title.position="top", title.hjust = 0.5, title = "Frequency"),
           size = guide_legend(title.position="top", title.hjust = 0.5)) +
    labs(subtitle = "Panel C: Average Citizens", x = "Influence on Content", y = "Influence on Vote")

leg <- get_legend(g_c) # Pull out legend to put in own facet
g_legend <- as_ggplot(leg)

g_correlation <- ggarrange(g_pl, g_pw, g_c, g_legend, ncol=2, nrow=2, common.legend = TRUE, legend="none")
ggsave(dpi = 900, file="Appendix Figure 1.png", g_correlation, width = 8, height = 8)


g_wl <- ggplot(runningcounts_winners_losers, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 150), breaks=seq(0, 150, by = 25)) + 
    geom_text(aes(label = paste0(Freq), color = Freq > 500)) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    labs(x = "Positively Affected Citizens' Influence", y = "Negatively Affected Citizens' Influence")

panel_height = unit(1,"npc") - sum(ggplotGrob(g_c)[["heights"]][-3]) - unit(1,"line") # Increase legend size
g_wl <- g_wl + guides(fill= guide_colorbar(barheight=panel_height, title="Frequency"))
ggsave(dpi = 900, file="Figure 1.png", g_wl)

g_cl <- ggplot(runningcounts_citizens_losers, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 400), breaks=seq(0, 400, by = 100)) + 
    geom_text(aes(label = paste0(Freq), color = Freq > 500)) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    labs(x = "Average Americans' Influence", y = "Negatively Affected Citizens' Influence")

panel_height = unit(1,"npc") - sum(ggplotGrob(g_cl)[["heights"]][-3]) - unit(1,"line") # Increase legend size
g_cl <- g_cl + guides(fill= guide_colorbar(barheight=panel_height, title="Frequency"))

g_cw <- ggplot(runningcounts_citizens_winners, aes(x = Var1, y = Var2)) +
    geom_tile(aes(fill = Freq), colour = "black") +
    scale_fill_gradient(low = "white", high = col_scheme[1], limits = c(0, 400), breaks=seq(0, 400, by = 100)) + 
    geom_text(aes(label = paste0(Freq), color = Freq > 500)) +
    scale_color_manual(guide = "none", values = c("gray40", "gray80")) +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    labs(x = "Average Americans' Influence", y = "Positively Affected Citizens' Influence")

panel_height = unit(1,"npc") - sum(ggplotGrob(g_cw)[["heights"]][-3]) - unit(1,"line") # Increase legend size
g_cw <- g_cw + guides(fill= guide_colorbar(barheight=panel_height, title="Frequency"))

g_incluence_correlation <- ggarrange(g_cl, g_cw, ncol=1, nrow=2, common.legend = TRUE, legend="right")
ggsave(dpi = 900, file="Online Appendix Figure 4.png", g_incluence_correlation, width = 5, height = 8)


## OLS Regression 

m_losers <- lm(formula = losers_influence ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_losers_no_demo <- lm(formula = losers_influence ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_losers_no_controls <- lm(formula = losers_influence ~ extefficacy_factor, data = democracy)

m_winners <- lm(formula = winners_influence ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_winners_no_demo <- lm(formula = winners_influence ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_winners_no_controls <- lm(formula = winners_influence ~ extefficacy_factor, data = democracy)

# Extract latex equation for inclusion in manuscript

extract_eq(m_winners, wrap = TRUE) # NB: Code adapted prior to insertion into word

# Prepare Regression Tables

stargazer(m_losers_no_controls, m_losers_no_demo, m_losers,
          dep.var.labels = "",
          dep.var.caption = "",
          covariate.labels = c("External Efficacy", 
                               "<b>Education (Ref: <bdo>&GreaterEqual;</bdo> Highschool)</b> <br>Some College", "College Degree", "Post-grad Degree",
                               "<b>Age (Ref: 18-24)</b> <br> 25-34", "35-44", "45-54", "55-64", "65+",
                               "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                               "<b>Political Interest (Ref: Not at All)</b> <br>Little interested", "Fairly interested", "Very interested", 
                               "<b>Partisanship (Ref: Independent)</b> <br>Democrat", "Republican"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("Cells contain OLS regression coefficients, with standard errors in parentheses.<br>+ <i>p</i> < 0.1; * <i>p</i> < 0.05; ** <i>p</i> < 0.01; *** <i>p</i> < 0.001."), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 3.htm")

stargazer(m_winners_no_controls, m_winners_no_demo, m_winners,
          dep.var.labels = "",
          dep.var.caption = "",
          covariate.labels = c("External Efficacy", 
                               "<b>Education (Ref: <bdo>&GreaterEqual;</bdo> Highschool)</b> <br>Some College", "College Degree", "Post-grad Degree",
                               "<b>Age (Ref: 18-24)</b> <br> 25-34", "35-44", "45-54", "55-64", "65+",
                               "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                               "<b>Political Interest (Ref: Not at All)</b> <br>Little interested", "Fairly interested", "Very interested", 
                               "<b>Partisanship (Ref: Independent)</b> <br>Democrat", "Republican"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("Cells contain OLS regression coefficients, with standard errors in parentheses.<br>+ <i>p</i> < 0.1; * <i>p</i> < 0.05; ** <i>p</i> < 0.01; *** <i>p</i> < 0.001."), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 4.htm")

# Put model estimates into temporary data.frames:
model1Frame <- data.frame(Coefficient = summary(m_losers)$coef[c("extefficacy_factor"), 1],
                          SE = summary(m_losers)$coef[c("extefficacy_factor"), 2],
                          modelName = "",
                          group = "Negatively Affected Citizens")

model2Frame <- data.frame(Coefficient = summary(m_winners)$coef[c("extefficacy_factor"), 1],
                          SE = summary(m_winners)$coef[c("extefficacy_factor"), 2],
                          modelName = "",
                          group = "Positively Affected Citizens")

# Combine these data.frames
allModelFrame <- data.frame(rbind(model1Frame, model2Frame))  

# Generate Labels 
allModelFrame %>% mutate_if(is.factor, as.character) -> allModelFrame # Factors to char
allModelFrame <- cbind(Variable = "External Efficacy", allModelFrame)

# Specify the width of your confidence intervals
interval1 <- -qnorm((1-0.9)/2)  # 90% multiplier
interval2 <- -qnorm((1-0.95)/2)  # 95% multiplier

# Create data frames of model coefficients and standard errors
m_losers_Frame <- data.frame(Variable = rownames(summary(m_losers)$coef[, 0]),
                             Coefficient = summary(m_losers)$coef[, 1],
                             SE = summary(m_losers)$coef[, 2]) %>% 
    slice(-1) %>% 
    add_row(.after = 1) %>% # Add space for empty Refs
    add_row(.after = 5) %>% 
    add_row(.after = 15) %>% 
    add_row(.after = 19) %>% 
    mutate(group = "Negatively Affected Citizens", 
           Variable = c("External Efficacy", 
                        "<i>Education<br>(Ref: ≤ Highschool)</i>", "Some College", "College Degree", "Post-grad Degree",
                        "<i>Age<br>(Ref: 18-24)</i>", "25-34", "35-44", "45-54", "55-64", "65+",
                        "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                        "<i>Political Interest<br>(Ref: Not at All)</i>", "Little interested", "Fairly interested", "Very interested", 
                        "<i>Partisanship<br>(Ref: Independent)</i>", "Democrat", "Republican"),
           Variable = factor(Variable, levels = rev(Variable)))

m_winners_Frame <- data.frame(Variable = rownames(summary(m_winners)$coef[, 0]),
                              Coefficient = summary(m_winners)$coef[, 1],
                              SE = summary(m_winners)$coef[, 2]) %>% 
    slice(-1) %>% 
    add_row(.after = 1) %>% # Add space for empty Refs
    add_row(.after = 5) %>% 
    add_row(.after = 15) %>% 
    add_row(.after = 19) %>% 
    mutate(group = "Positively Affected Citizens", 
           Variable = c("External Efficacy", 
                        "<i>Education<br>(Ref: ≤ Highschool)</i>", "Some College", "College Degree", "Post-grad Degree",
                        "<i>Age<br>(Ref: 18-24)</i>", "25-34", "35-44", "45-54", "55-64", "65+",
                        "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                        "<i>Political Interest<br>(Ref: Not at All)</i>", "Little interested", "Fairly interested", "Very interested", 
                        "<i>Partisanship<br>(Ref: Independent)</i>", "Democrat", "Republican"),
           Variable = factor(Variable, levels = rev(Variable)))

fullModels_Frame <- data.frame(rbind(m_losers_Frame, m_winners_Frame))
fullModels_Frame$group = factor(fullModels_Frame$group, levels=c("Negatively Affected Citizens", "Positively Affected Citizens"))


full_coefficients <- ggplot(fullModels_Frame) +
    geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) + 
    geom_linerange(aes(x = Variable, ymin = Coefficient - SE*interval1,
                       ymax = Coefficient + SE*interval1),
                   lwd = 1, position = position_dodge(width = 1/2), show.legend=FALSE, colour = col_scheme[1]) + 
    geom_pointrange(aes(x = Variable, y = Coefficient, ymin = Coefficient - SE*interval2,
                        ymax = Coefficient + SE*interval2),
                    lwd = 1/2, position = position_dodge(width = 1/2), fill = "WHITE", colour = col_scheme[1]) +
    labs(x = NULL) + 
    theme(text = element_text(size = 30),
          strip.text.x = element_text(size = 30),
          axis.text.y = element_markdown(),
          axis.ticks.y = element_line(colour = NA),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    scale_y_continuous(expand = c(0, 0.01)) +
    coord_flip() +
    facet_grid(~ group, scales = "free_x")

ggsave(dpi = 300, file="Figure 2.png", full_coefficients, width = 16, height = 20)


# Prep graph legend so that symbols will align with figure
GeomPointrange$draw_key <-  function (data, params, size)     {
    
    draw_key_vpath <- function (data, params, size) {
        # only need to change the x&y coords so that the line is horizontal
        # originally, the vertical line was `0.5, 0.1, 0.5, 0.9`
        segmentsGrob(0.1, 0.5, 0.9, 0.5, 
                     gp = gpar(col = alpha(data$colour, data$alpha), 
                               lwd = data$size * .pt, lty = data$linetype, 
                               lineend = "butt"), arrow = params$arrow)
    }
    
    grobTree(draw_key_vpath(data, params, size), 
             draw_key_point(transform(data, size = data$size * 4), params))
}


# Plot

g_lw_coefficients <- ggplot(allModelFrame, aes(colour = group)) +
    geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) + 
    geom_linerange(aes(x = Variable, ymin = Coefficient - SE*interval1,
                       ymax = Coefficient + SE*interval1),
                   lwd = 1, position = position_dodge(width = 1/2), show.legend=FALSE) + 
    geom_pointrange(aes(x = Variable, y = Coefficient, ymin = Coefficient - SE*interval2,
                        ymax = Coefficient + SE*interval2, shape = group),
                    lwd = 1/2, position = position_dodge(width = 1/2), fill = "WHITE") +
    labs(title = "Panel B: Preferred Relative Influence", 
         x = "", colour = "Dependent Variable:", shape = "Dependent Variable:") +
    theme(legend.title = element_text(size = 20),
          text = element_text(size = 24),
          axis.text.x = element_text(size = 24),
          axis.text.y = element_text(size = 24),
          legend.position = c(.3, .89),
          legend.box.just = "left",
          legend.margin = margin(8, 8, 8, 8),
          strip.background = element_rect(fill = alpha(col_scheme[1], .005))) +
    scale_y_continuous(breaks = round(seq(-.15, .15, by = 0.05), 2)) +
    scale_color_manual(values = col_scheme)

# Graphs should exclude extreme values (x-scale from 5th to 95th percentile)
x_ext_range <- quantile(democracy$extefficacy_factor, probs = c(.05, .95))

# Predicted values plots 

m_losers_ext_dat <- cplot(m_losers, "extefficacy_factor", 
                          xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
m_losers_ext_dat$group <- "Negatively Affected Citizens"
m_losers_ext_dat$efficacy <- "External Efficacy"

m_winners_ext_dat <- cplot(m_winners, "extefficacy_factor", 
                           xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
m_winners_ext_dat$group <- "Positively Affected Citizens"
m_winners_ext_dat$efficacy <- "External Efficacy"

# Combine data
efficacy_dat <- rbind.fill(m_losers_ext_dat, m_winners_ext_dat)
efficacy_dat$group = factor(efficacy_dat$group, levels=c("Negatively Affected Citizens", "Positively Affected Citizens"))

# Plot 
g_pred <- ggplot(efficacy_dat, aes(x = xvals)) + 
    geom_line(aes(y = yvals), colour = col_scheme[1]) +
    geom_ribbon(aes(ymin = lower, ymax = upper), linetype = 0, 
                alpha = 0.1, colour = col_scheme[1], fill = col_scheme[1]) +
    xlab("External Efficacy") + 
    ylab("Predicted Value") + 
    facet_grid(. ~ group) +
    labs(colour = "Dependent Variable:") +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005)),
          text = element_text(size = 17),
          strip.text.x = element_text(size = 17), strip.text.y = element_text(size = 14)) +
    scale_color_manual(values = col_scheme) 

ggsave(dpi = 600, file="Figure 3.png", g_pred, width = 9, height = 7)

# For in-text discussion 
losers_influence_SD <- sd(democracy$losers_influence)
winners_influence_SD <- sd(democracy$winners_influence)

m_losers_ext_dat %>%
    slice(1, 10) %>%
    select(yvals)

m_losers_ext_dat %>%
    slice(1, 10) %>%
    select(yvals) %>%
    summarise(difference = `yvals` - lag(`yvals`)) %>%
    mutate(percent_of_sd = difference/losers_influence_SD) %>%
    slice(2)

m_winners_ext_dat %>%
    slice(1, 10) %>%
    select(yvals) 

m_winners_ext_dat %>%
    slice(1, 10) %>%
    select(yvals) %>%
    summarise(difference = `yvals` - lag(`yvals`)) %>%
    mutate(percent_of_sd = difference/winners_influence_SD) %>%
    slice(2)

wilcox.test(democracy$losers_influence, democracy$winners_influence, paired = TRUE)

t.test(democracy$losers_influence, democracy$winners_influence)
    
### Robustness checks 

## Check 1: Decompose the composite indices 

## OLS regressions 

m_citizens_details <- lm(formula = citizens_details ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_citizens_details_no_demo <- lm(formula = citizens_details ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_citizens_details_no_controls <- lm(formula = citizens_details ~ extefficacy_factor, data = democracy)

m_citizens_vote <- lm(formula = citizens_vote ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_citizens_vote_no_demo <- lm(formula = citizens_vote ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_citizens_vote_no_controls <- lm(formula = citizens_vote ~ extefficacy_factor, data = democracy)

m_losers_details <- lm(formula = losers_details ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_losers_details_no_demo <- lm(formula = losers_details ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_losers_details_no_controls <- lm(formula = losers_details ~ extefficacy_factor, data = democracy)

m_losers_vote <- lm(formula = losers_vote ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_losers_vote_no_demo <- lm(formula = losers_vote ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_losers_vote_no_controls <- lm(formula = losers_vote ~ extefficacy_factor, data = democracy)

m_winners_details <- lm(formula = winners_details ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_winners_details_no_demo <- lm(formula = winners_details ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_winners_details_no_controls <- lm(formula = winners_details ~ extefficacy_factor, data = democracy)

m_winners_vote <- lm(formula = winners_vote ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy)
m_winners_vote_no_demo <- lm(formula = winners_vote ~ extefficacy_factor + education_cat + age + income + female + minority, data = democracy)
m_winners_vote_no_controls <- lm(formula = winners_vote ~ extefficacy_factor, data = democracy)

# Prepare Regression Tables

stargazer(m_losers_details_no_controls, m_losers_details_no_demo, m_losers_details, m_losers_vote_no_controls, m_losers_vote_no_demo, m_losers_vote,
          dep.var.labels = c("Influence on Details", "Influence on Votes"),
          dep.var.caption = "",
          covariate.labels = c("External Efficacy", 
                               "<b>Education (Ref: <bdo>&GreaterEqual;</bdo> Highschool)</b> <br>Some College", "College Degree", "Post-grad Degree",
                               "<b>Age (Ref: 18-24)</b> <br> 25-34", "35-44", "45-54", "55-64", "65+",
                               "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                               "<b>Political Interest (Ref: Not at All)</b> <br>Little interested", "Fairly interested", "Very interested", 
                               "<b>Partisanship (Ref: Independent)</b> <br>Democrat", "Republican"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("Cells contain OLS regression coefficients, with standard errors in parentheses.<br>+ <i>p</i> < 0.1; * <i>p</i> < 0.05; ** <i>p</i> < 0.01; *** <i>p</i> < 0.001."), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 5.htm")

stargazer(m_winners_details_no_controls, m_winners_details_no_demo, m_winners_details, m_winners_vote_no_controls, m_winners_vote_no_demo, m_winners_vote,
          dep.var.labels = c("Influence on Details", "Influence on Votes"),
          dep.var.caption = "",
          covariate.labels = c("External Efficacy", 
                               "<b>Education (Ref: <bdo>&GreaterEqual;</bdo> Highschool)</b> <br>Some College", "College Degree", "Post-grad Degree",
                               "<b>Age (Ref: 18-24)</b> <br> 25-34", "35-44", "45-54", "55-64", "65+",
                               "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                               "<b>Political Interest (Ref: Not at All)</b> <br>Little interested", "Fairly interested", "Very interested", 
                               "<b>Partisanship (Ref: Independent)</b> <br>Democrat", "Republican"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("Cells contain OLS regression coefficients, with standard errors in parentheses.<br>+ <i>p</i> < 0.1; * <i>p</i> < 0.05; ** <i>p</i> < 0.01; *** <i>p</i> < 0.001."), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 6.htm")

## Check 2: Ordered logit of the two component measures, recoding the DVs to be 3 categories (less, the same, more)

## Ordered logistic regression 

m_losers_details_check2 <- polr(formula = as.factor(losers_details_3) ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy, Hess=TRUE)
m_losers_vote_check2 <- polr(formula = as.factor(losers_vote_3) ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy, Hess=TRUE)

m_winners_details_check2 <- polr(formula = as.factor(winners_details_3) ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy, Hess=TRUE)
m_winners_vote_check2 <- polr(formula = as.factor(winners_vote_3) ~ extefficacy_factor + education_cat + age + income + female + minority + citizens_influence + polinterest + relevel(pid_3, ref = "Independent"), data = democracy, Hess=TRUE)

# Prepare Regression Tables

stargazer(m_losers_details_check2, m_losers_vote_check2, m_winners_details_check2, m_winners_vote_check2, 
          dep.var.labels = c("Negatively Affected Citizens - Details", "Negatively Affected Citizens - Votes", "Positively Affected Citizens - Details", "Positively Affected Citizens - Votes"),
          dep.var.caption = "",
          covariate.labels = c("External Efficacy", 
                               "<b>Education (Ref: <bdo>&GreaterEqual;</bdo> Highschool)</b> <br>Some College", "College Degree", "Post-grad Degree",
                               "<b>Age (Ref: 18-24)</b> <br> 25-34", "35-44", "45-54", "55-64", "65+",
                               "Income", "Female", "Ethnic Minority", "Preferred Citizen Influence",
                               "<b>Political Interest (Ref: Not at All)</b> <br>Little interested", "Fairly interested", "Very interested", 
                               "<b>Partisanship (Ref: Independent)</b> <br>Democrat", "Republican"),
          single.row = TRUE, no.space=TRUE, 
          star.cutoffs = c(.1, .05, .01, .001), star.char = c("+", "*", "**", "***"),
          notes = c("Cells contain ordered logistic regression coefficients, with standard errors in parentheses.<br>+ <i>p</i> < 0.1; * <i>p</i> < 0.05; ** <i>p</i> < 0.01; *** <i>p</i> < 0.001."), notes.append = FALSE,
          type = "html", out = "Online Appendix Table 7.htm")

## Check 3: Include internal efficacy 
m_losers_check3 <- lm(formula = losers_influence ~ extefficacy_factor + intefficacy_factor + citizens_influence + polinterest + relevel(pid_3, ref = "Independent") + education_cat + age + income + female + minority, data = democracy)
m_winners_check3 <- lm(formula = winners_influence ~ extefficacy_factor + intefficacy_factor + citizens_influence + polinterest + relevel(pid_3, ref = "Independent") + education_cat + age + income + female + minority, data = democracy)

# Predicted values plots 
m_losers_ext_dat_check3 <- cplot(m_losers_check3, "extefficacy_factor", 
                          xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
m_losers_ext_dat_check3$group <- "Negatively Affected Citizens"
m_losers_ext_dat_check3$efficacy <- "External Efficacy"

m_winners_ext_dat_check3 <- cplot(m_winners_check3, "extefficacy_factor", 
                           xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
m_winners_ext_dat_check3$group <- "Positively Affected Citizens"
m_winners_ext_dat_check3$efficacy <- "External Efficacy"

# Combine data
efficacy_dat_check3 <- rbind.fill(m_losers_ext_dat_check3, m_winners_ext_dat_check3)

# Plot 

g_pred_check3 <- ggplot(efficacy_dat_check3, aes(x = xvals)) + 
    geom_line(aes(y = yvals), colour = col_scheme[1]) +
    geom_ribbon(aes(ymin = lower, ymax = upper), linetype = 0, 
                alpha = 0.1, colour = col_scheme[1], fill = col_scheme[1]) +
    xlab("External Efficacy") + 
    ylab("Predicted Value") + 
    facet_grid(. ~ group) +
    labs(colour = "Dependent Variable:") +
    theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005)),
          text = element_text(size = 13),
          strip.text.x = element_text(size = 14), strip.text.y = element_text(size = 14)) +
    scale_color_manual(values = col_scheme) 

ggsave(dpi = 900, file="Check_3.png", g_pred_check3, width = 7, height = 9)


## Check 4: alternative controls - replacing factor controls with their numeric counterparts (e.g. age, education) 

# Prep function
varying_the_controls <- function(controls) {
   
    # Regressions 
    m_losers_check <- lm(as.formula(paste("losers_influence ~ ", controls)), data = democracy)
    m_winners_check <- lm(as.formula(paste("winners_influence ~ ", controls)), data = democracy)
    
    # Margins
    m_losers_ext_dat_check <- cplot(m_losers_check, "extefficacy_factor", 
                                    xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
    m_losers_ext_dat_check$group <- "Negatively Affected Citizens"
    m_losers_ext_dat_check$efficacy <- "External Efficacy"
    
    m_winners_ext_dat_check <- cplot(m_winners_check, "extefficacy_factor", 
                                     xvals = seq(min(x_ext_range), max(x_ext_range), length.out = 10), draw = FALSE, level = 0.835)
    m_winners_ext_dat_check$group <- "Positively Affected Citizens"
    m_winners_ext_dat_check$efficacy <- "External Efficacy"
    
    # Combine data
    efficacy_dat_check <- rbind.fill(m_losers_ext_dat_check, m_winners_ext_dat_check)
    
    # Plot 
    g_pred_check <- ggplot(efficacy_dat_check, aes(x = xvals)) + 
        geom_line(aes(y = yvals), colour = col_scheme[1]) +
        geom_ribbon(aes(ymin = lower, ymax = upper), linetype = 0, 
                    alpha = 0.1, colour = col_scheme[1], fill = col_scheme[1]) +
        xlab("External Efficacy") + 
        ylab("Predicted Value") + 
        facet_grid(group ~ efficacy, scales = "free") +
        labs(colour = "Dependent Variable:") +
        theme(strip.background = element_rect(fill = alpha(col_scheme[1], .005)),
              text = element_text(size = 13),
              strip.text.x = element_text(size = 14), strip.text.y = element_text(size = 14)) +
        scale_color_manual(values = col_scheme) 
    
    # Save figure, using name of inputted object
    name <- deparse(substitute(controls))
    ggsave(dpi = 900, file=paste(name,".png",sep=""), g_pred_check, width = 7, height = 9)
    
}

# Run with different controls 
numeric_interest <- 'extefficacy_factor + as.numeric(polinterest) + relevel(pid_3, ref = "Independent") + education_cat + age + income + female + minority'
varying_the_controls(numeric_interest)

numeric_education <- 'extefficacy_factor + polinterest + relevel(pid_3, ref = "Independent") + education + age + income + female + minority'
varying_the_controls(numeric_education)

numeric_age <- 'extefficacy_factor + polinterest + relevel(pid_3, ref = "Independent") + education_cat + as.numeric(age) + income + female + minority'
varying_the_controls(numeric_age)

numeric_all <- 'extefficacy_factor + as.numeric(polinterest) + relevel(pid_3, ref = "Independent") + education + as.numeric(age) + income + female + minority'
varying_the_controls(numeric_all)
